!     #########
      SUBROUTINE WRITESURF_PGD_TEB_PAR_n (BDD, DTB, DTGD, DTGR, DTH, DTT, DGU, &
                                          U, TGDO, TGDP, TGRO, TIR, TOP,       &
                                          HPROGRAM)
!     ################################################
!
!!****  *WRITESURF_PGD_TEB_PAR_n* - reads ISBA physiographic fields
!!                        
!!
!!    PURPOSE
!!    -------
!!
!!**  METHOD
!!    ------
!!
!!    EXTERNAL
!!    --------
!!
!!
!!    IMPLICIT ARGUMENTS
!!    ------------------
!!
!!    REFERENCE
!!    ---------
!!
!!
!!    AUTHOR
!!    ------
!!      V. Masson   *Meteo France*
!!
!!    MODIFICATIONS
!!    -------------
!!      Original    05/2005
!!       V. Masson  08/2013 add solar panels
!-------------------------------------------------------------------------------
!
!*       0.    DECLARATIONS
!              ------------
!
!
!
!

!
!
USE MODD_BLD_DESCRIPTION_n, ONLY : BLD_DESC_t
USE MODD_DATA_BEM_n, ONLY : DATA_BEM_t
USE MODD_DATA_TEB_GARDEN_n, ONLY : DATA_TEB_GARDEN_t
USE MODD_DATA_TEB_GREENROOF_n, ONLY : DATA_TEB_GREENROOF_t
USE MODD_DATA_TEB_HYDRO_n, ONLY : DATA_TEB_HYDRO_t
USE MODD_DATA_TEB_n, ONLY : DATA_TEB_t
USE MODD_DIAG_SURF_ATM_n, ONLY : DIAG_SURF_ATM_t
USE MODD_SURF_ATM_n, ONLY : SURF_ATM_t
USE MODD_TEB_GARDEN_OPTION_n, ONLY : TEB_GARDEN_OPTIONS_t
USE MODD_TEB_GARDEN_PGD_n, ONLY : TEB_GARDEN_PGD_t
USE MODD_TEB_GREENROOF_OPTION_n, ONLY : TEB_GREENROOF_OPTIONS_t
USE MODD_TEB_IRRIG_n, ONLY : TEB_IRRIG_t
USE MODD_TEB_OPTION_n, ONLY : TEB_OPTIONS_t
!
USE MODI_WRITE_SURF
USE MODI_WRITE_BLD_DESCRIPTION_n
USE MODI_WRITESURF_PGD_TEB_IRRIG_n
!
!
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK
USE PARKIND1  ,ONLY : JPRB
!
IMPLICIT NONE
!
!*       0.1   Declarations of arguments
!              -------------------------
!
!
TYPE(BLD_DESC_t), INTENT(INOUT) :: BDD
TYPE(DATA_BEM_t), INTENT(INOUT) :: DTB
TYPE(DATA_TEB_GARDEN_t), INTENT(INOUT) :: DTGD
TYPE(DATA_TEB_GREENROOF_t), INTENT(INOUT) :: DTGR
TYPE(DATA_TEB_HYDRO_t), INTENT(INOUT) :: DTH
TYPE(DATA_TEB_t), INTENT(INOUT) :: DTT
TYPE(DIAG_SURF_ATM_t), INTENT(INOUT) :: DGU
TYPE(SURF_ATM_t), INTENT(INOUT) :: U
TYPE(TEB_GARDEN_OPTIONS_t), INTENT(INOUT) :: TGDO
TYPE(TEB_GARDEN_PGD_t), INTENT(INOUT) :: TGDP
TYPE(TEB_GREENROOF_OPTIONS_t), INTENT(INOUT) :: TGRO
TYPE(TEB_IRRIG_t), INTENT(INOUT) :: TIR
TYPE(TEB_OPTIONS_t), INTENT(INOUT) :: TOP
!
 CHARACTER(LEN=6),  INTENT(IN)  :: HPROGRAM ! program calling
!
!*       0.2   Declarations of local variables
!              -------------------------------
!
INTEGER           :: IRESP          ! IRESP  : return-code if a problem appears
 CHARACTER(LEN=12) :: YRECFM        ! Name of the article to be read
 CHARACTER(LEN=100):: YCOMMENT      ! Comment string
INTEGER           :: JLAYER         ! loop index
INTEGER           :: JCOMP          ! loop index
INTEGER           :: JTIME          ! loop index
INTEGER           :: JSCHED         ! loop index
REAL, DIMENSION(:), ALLOCATABLE :: ZWORK
REAL(KIND=JPRB) :: ZHOOK_HANDLE
!
!-------------------------------------------------------------------------------
!
IF (LHOOK) CALL DR_HOOK('WRITESURF_PGD_TEB_PAR_N',0,ZHOOK_HANDLE)
YRECFM='L_BLDTYPE'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_BLDTYPE,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_BLDTYPE) THEN
  YRECFM='D_BLDTYPE'
  YCOMMENT='X_Y_'//YRECFM//' (1)'
  ALLOCATE(ZWORK(SIZE(DTT%NPAR_BLDTYPE)))
  ZWORK=FLOAT(DTT%NPAR_BLDTYPE(:))
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,ZWORK,IRESP,YCOMMENT)
  DEALLOCATE(ZWORK)
ENDIF
!
YRECFM='L_P1TERR'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, &
   HPROGRAM,YRECFM,DTT%LDATA_P1TERRITORY,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_P1TERRITORY) THEN
   YRECFM='D_P1TERR'
   YCOMMENT='X_Y_'//YRECFM//'   '
   ALLOCATE(ZWORK(SIZE(DTT%NPAR_P1TERRITORY)))
   ZWORK=FLOAT(DTT%NPAR_P1TERRITORY(:))
   CALL WRITE_SURF(DGU, U, &
      HPROGRAM,YRECFM,ZWORK,IRESP,YCOMMENT)
   DEALLOCATE(ZWORK)
ENDIF
!
YRECFM='L_PXTERR'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, &
   HPROGRAM,YRECFM,DTT%LDATA_PXTERRITORY,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_PXTERRITORY) THEN
   YRECFM='D_PXTERR'
   YCOMMENT='X_Y_'//YRECFM//'   '
   ALLOCATE(ZWORK(SIZE(DTT%NPAR_PXTERRITORY)))
   ZWORK=FLOAT(DTT%NPAR_PXTERRITORY(:))
   CALL WRITE_SURF(DGU, U, &
      HPROGRAM,YRECFM,ZWORK,IRESP,YCOMMENT)
   DEALLOCATE(ZWORK)
ENDIF
!
YRECFM='L_IBLDAGE'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_IND_BLD_AGE,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_IND_BLD_AGE) THEN
  YRECFM='D_IBLDAGE'
  YCOMMENT='X_Y_'//YRECFM//' ()'
  ALLOCATE(ZWORK(SIZE(DTT%NPAR_IND_BLD_AGE)))
  ZWORK=FLOAT(DTT%NPAR_IND_BLD_AGE(:))
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,ZWORK,IRESP,YCOMMENT)
  DEALLOCATE(ZWORK)
ENDIF
!
YRECFM='L_CBLDAGE'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_COL_BLD_AGE,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_COL_BLD_AGE) THEN
  YRECFM='D_CBLDAGE'
  YCOMMENT='X_Y_'//YRECFM//' ()'
  ALLOCATE(ZWORK(SIZE(DTT%NPAR_COL_BLD_AGE)))
  ZWORK=FLOAT(DTT%NPAR_COL_BLD_AGE(:))
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,ZWORK,IRESP,YCOMMENT)
  DEALLOCATE(ZWORK)
ENDIF
!
YRECFM='L_USETYPE'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_USETYPE,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_USETYPE) THEN
  YRECFM='D_USETYPE'
  YCOMMENT='X_Y_'//YRECFM//' (m)'
  ALLOCATE(ZWORK(SIZE(DTT%NPAR_USETYPE)))
  ZWORK=FLOAT(DTT%NPAR_USETYPE(:))
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,ZWORK,IRESP,YCOMMENT)
  DEALLOCATE(ZWORK)
ENDIF
!
IF (DTT%LDATA_BLDTYPE.OR.DTT%LDATA_IND_BLD_AGE.OR.DTT%LDATA_COL_BLD_AGE.OR.  &
    DTT%LDATA_USETYPE.OR.DTT%LDATA_P1TERRITORY.OR.DTT%LDATA_PXTERRITORY) THEN
   CALL WRITE_BLD_DESCRIPTION_n(DGU, U, BDD, HPROGRAM)
ENDIF
!
YRECFM='L_FRACIHS'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FRACIHS,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FRACIHS) THEN
   YRECFM='D_FRACIHS'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FRACIHS,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FRACCHS'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FRACCHS,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FRACCHS) THEN
   YRECFM='D_FRACCHS'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
  CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FRACCHS,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FRACCOM'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FRACCOM,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FRACCOM) THEN
   YRECFM='D_FRACCOM'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FRACCOM,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FRACTER'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FRACTER,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FRACTER) THEN
   YRECFM='D_FRACTER'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FRACTER,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FRACIND'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FRACIND,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FRACIND) THEN
   YRECFM='D_FRACIND'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FRACIND,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FRACPAV'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FRACPAV,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FRACPAV) THEN
   YRECFM='D_FRACPAV'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FRACPAV,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FRACMRI'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FRACMRI,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FRACMRI) THEN
   YRECFM='D_FRACMRI'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FRACMRI,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FRACHRI'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FRACHRI,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FRACHRI) THEN
   YRECFM='D_FRACHRI'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FRACHRI,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FRACATB'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FRACATB,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FRACATB) THEN
   YRECFM='D_FRACATB'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FRACATB,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FOEQI_MAIS'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FOEQI_MAIS,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FOEQI_MAIS) THEN
   YRECFM='D_FOEQI_MAIS'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FOEQI_MAIS,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FOEQI_APPT'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FOEQI_APPT,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FOEQI_APPT) THEN
   YRECFM='D_FOEQI_APPT'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FOEQI_APPT,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FAEQI_MAIS'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FAEQI_MAIS,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FAEQI_MAIS) THEN
   YRECFM='D_FAEQI_MAIS'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FAEQI_MAIS,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FAEQI_APPT'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_FAEQI_APPT,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FAEQI_APPT) THEN
   YRECFM='D_FAEQI_APPT'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_FAEQI_APPT,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_CRE_MAIS'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_CRE_MAIS,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_CRE_MAIS) THEN
   YRECFM='D_CRE_MAIS'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_CRE_MAIS,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_CRE_APPT'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_CRE_APPT,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_CRE_APPT) THEN
   YRECFM='D_CRE_APPT'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_CRE_APPT,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_EFF_HEAT'
YCOMMENT=YRECFM
CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%LDATA_EFF_HEAT,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_EFF_HEAT) THEN
   YRECFM='D_EFF_HEAT'
   YCOMMENT='X_Y_'//YRECFM//' (1)'
   CALL WRITE_SURF(DGU, U, HPROGRAM,YRECFM,DTT%XPAR_EFF_HEAT,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_Z0_TOWN'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_Z0_TOWN,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_Z0_TOWN) THEN
  YRECFM='D_Z0_TOWN'
  YCOMMENT='X_Y_'//YRECFM//' (m)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_Z0_TOWN,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_BLD'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_BLD,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_BLD) THEN
  YRECFM='D_BLDFRA'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_BLD,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_GARDEN'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_GARDEN,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_GARDEN) THEN
  YRECFM='D_GARDEN'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_GARDEN,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_GREENROOF'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_GREENROOF,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_GREENROOF) THEN
  YRECFM='D_GREENROOF'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_GREENROOF,IRESP,YCOMMENT)
ENDIF
!
!YRECFM='L_URBTREE'
!YCOMMENT=YRECFM
! CALL WRITE_SURF(DGU, U, &
!                 HPROGRAM,YRECFM,DTT%LDATA_URBTREE,IRESP,HCOMMENT=YCOMMENT)
!IF (DTT%LDATA_URBTREE) THEN
!  YRECFM='D_URBTREE'
!  YCOMMENT='X_Y_'//YRECFM//' (-)'
!  CALL WRITE_SURF(DGU, U, &
!                 HPROGRAM,YRECFM,DTT%XPAR_URBTREE,IRESP,YCOMMENT)
!ENDIF
!
YRECFM='L_ROAD_DIR'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_ROAD_DIR,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_ROAD_DIR) THEN
  YRECFM='D_ROAD_DIR'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_ROAD_DIR,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_ALB_ROOF'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_ALB_ROOF,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_ALB_ROOF) THEN
  YRECFM='D_ALB_ROOF'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_ALB_ROOF,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_EMIS_ROOF'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_EMIS_ROOF,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_EMIS_ROOF) THEN
  YRECFM='D_EMI_ROOF'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_EMIS_ROOF,IRESP,YCOMMENT)
ENDIF
!
IF (DTT%LDATA_HC_ROOF) THEN
  YCOMMENT='Number of specified Roof thermal layers'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,'PAR_RF_LAYER',DTT%NPAR_ROOF_LAYER,IRESP,YCOMMENT)
END IF
!
YRECFM='L_HC_ROOF'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_HC_ROOF,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_HC_ROOF) THEN
  DO JLAYER=1,DTT%NPAR_ROOF_LAYER
    WRITE(YRECFM,FMT='(A9,I1.1)') 'D_HC_ROOF',JLAYER
    YCOMMENT='X_Y_'//YRECFM//' (J/K/m3)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_HC_ROOF(:,JLAYER),IRESP,YCOMMENT)
  END DO
ENDIF
!
YRECFM='L_TC_ROOF'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_TC_ROOF,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_TC_ROOF) THEN
  DO JLAYER=1,DTT%NPAR_ROOF_LAYER
    WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TC_ROOF',JLAYER
    YCOMMENT='X_Y_'//YRECFM//' (W/K/m)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_TC_ROOF(:,JLAYER),IRESP,YCOMMENT)
  END DO
ENDIF
!
YRECFM='L_D_ROOF'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_D_ROOF,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_D_ROOF) THEN
  DO JLAYER=1,DTT%NPAR_ROOF_LAYER
    WRITE(YRECFM,FMT='(A8,I1.1)') 'D_D_ROOF',JLAYER
    YCOMMENT='X_Y_'//YRECFM//' (m)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_D_ROOF(:,JLAYER),IRESP,YCOMMENT)
  END DO
ENDIF
!
YRECFM='L_ALB_ROAD'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_ALB_ROAD,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_ALB_ROAD) THEN
  YRECFM='D_ALB_ROAD'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_ALB_ROAD,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_EMIS_ROAD'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_EMIS_ROAD,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_EMIS_ROAD) THEN
  YRECFM='D_EMI_ROAD'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_EMIS_ROAD,IRESP,YCOMMENT)
ENDIF
!
IF (DTT%LDATA_HC_ROAD) THEN
  YCOMMENT='Number of specified Road thermal layers'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,'PAR_RD_LAYER',DTT%NPAR_ROAD_LAYER,IRESP,YCOMMENT)
END IF
!
YRECFM='L_HC_ROAD'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_HC_ROAD,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_HC_ROAD) THEN
  DO JLAYER=1,DTT%NPAR_ROAD_LAYER
    WRITE(YRECFM,FMT='(A9,I1.1)') 'D_HC_ROAD',JLAYER
    YCOMMENT='X_Y_'//YRECFM//' (J/K/m3)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_HC_ROAD(:,JLAYER),IRESP,YCOMMENT)
  END DO
ENDIF
!
YRECFM='L_TC_ROAD'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_TC_ROAD,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_TC_ROAD) THEN
  DO JLAYER=1,DTT%NPAR_ROAD_LAYER
    WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TC_ROAD',JLAYER
    YCOMMENT='X_Y_'//YRECFM//' (W/K/m)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_TC_ROAD(:,JLAYER),IRESP,YCOMMENT)
  END DO
ENDIF
!
YRECFM='L_D_ROAD'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_D_ROAD,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_D_ROAD) THEN
  DO JLAYER=1,DTT%NPAR_ROAD_LAYER
    WRITE(YRECFM,FMT='(A8,I1.1)') 'D_D_ROAD',JLAYER
    YCOMMENT='X_Y_'//YRECFM//' (m)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_D_ROAD(:,JLAYER),IRESP,YCOMMENT)
  END DO
ENDIF
!
YRECFM='L_ALB_WALL'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_ALB_WALL,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_ALB_WALL) THEN
  YRECFM='D_ALB_WALL'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_ALB_WALL,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_EMIS_WALL'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_EMIS_WALL,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_EMIS_WALL) THEN
  YRECFM='D_EMI_WALL'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_EMIS_WALL,IRESP,YCOMMENT)
ENDIF
!
!
IF (DTT%LDATA_HC_WALL) THEN
  YCOMMENT='Number of specified Wall thermal layers'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,'PAR_WL_LAYER',DTT%NPAR_WALL_LAYER,IRESP,YCOMMENT)
END IF
!
YRECFM='L_HC_WALL'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_HC_WALL,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_HC_WALL) THEN
  DO JLAYER=1,DTT%NPAR_WALL_LAYER
    WRITE(YRECFM,FMT='(A9,I1.1)') 'D_HC_WALL',JLAYER
    YCOMMENT='X_Y_'//YRECFM//' (J/K/m3)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_HC_WALL(:,JLAYER),IRESP,YCOMMENT)
  END DO
ENDIF
!
YRECFM='L_TC_WALL'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_TC_WALL,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_TC_WALL) THEN
  DO JLAYER=1,DTT%NPAR_WALL_LAYER
    WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TC_WALL',JLAYER
    YCOMMENT='X_Y_'//YRECFM//' (W/K/m)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_TC_WALL(:,JLAYER),IRESP,YCOMMENT)
  END DO
ENDIF
!
YRECFM='L_D_WALL'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_D_WALL,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_D_WALL) THEN
  DO JLAYER=1,DTT%NPAR_WALL_LAYER
    WRITE(YRECFM,FMT='(A8,I1.1)') 'D_D_WALL',JLAYER
    YCOMMENT='X_Y_'//YRECFM//' (m)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_D_WALL(:,JLAYER),IRESP,YCOMMENT)
  END DO
ENDIF
!
YRECFM='L_BLD_HEIGHT'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_BLD_HEIGHT,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_BLD_HEIGHT) THEN
  YRECFM='D_BLD_HEIG'
  YCOMMENT='X_Y_'//YRECFM//' (m)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_BLD_HEIGHT,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_WALL_O_HOR'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_WALL_O_HOR,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_WALL_O_HOR) THEN
  YRECFM='D_WALL_O_H'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_WALL_O_HOR,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_H_TRAF'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_H_TRAFFIC,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_H_TRAFFIC) THEN
  YRECFM='D_H_TRAF'
  YCOMMENT='X_Y_'//YRECFM//' (W/m2)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_H_TRAFFIC,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_LE_TRAF'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_LE_TRAFFIC,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_LE_TRAFFIC) THEN
  YRECFM='D_LE_TRAF'
  YCOMMENT='X_Y_'//YRECFM//' (W/m2)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_LE_TRAFFIC,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_H_IND'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_H_INDUSTRY,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_H_INDUSTRY) THEN
  YRECFM='D_H_IND'
  YCOMMENT='X_Y_'//YRECFM//' (W/m2)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_H_INDUSTRY,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_LE_IND'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_LE_INDUSTRY,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_LE_INDUSTRY) THEN
  YRECFM='D_LE_IND'
  YCOMMENT='X_Y_'//YRECFM//' (W/m2)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_LE_INDUSTRY,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_ROUGH_ROOF'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_ROUGH_ROOF,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_ROUGH_ROOF) THEN
  YRECFM='D_ROUGH_ROOF'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_ROUGH_ROOF,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_ROUGH_WALL'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_ROUGH_WALL,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_ROUGH_WALL) THEN
  YRECFM='D_ROUGH_WALL'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_ROUGH_WALL,IRESP,YCOMMENT)
ENDIF
!
!* solar panels
!
YRECFM='L_EMIS_PANEL'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_EMIS_PANEL,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_EMIS_PANEL) THEN
  YRECFM='D_EMIS_PANEL'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_EMIS_PANEL,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_ALB_PANEL'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_ALB_PANEL,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_ALB_PANEL) THEN
  YRECFM='D_ALB_PANEL'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_ALB_PANEL,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_EFF_PANEL'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_EFF_PANEL,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_EFF_PANEL) THEN
  YRECFM='D_EFF_PANEL'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_EFF_PANEL,IRESP,YCOMMENT)
ENDIF
!
YRECFM='L_FRAC_PANEL'
YCOMMENT=YRECFM
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%LDATA_FRAC_PANEL,IRESP,HCOMMENT=YCOMMENT)
IF (DTT%LDATA_FRAC_PANEL) THEN
  YRECFM='D_FRAC_PANEL'
  YCOMMENT='X_Y_'//YRECFM//' (-)'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTT%XPAR_FRAC_PANEL,IRESP,YCOMMENT)
ENDIF
!
!* Building Energy Model
!
IF (TOP%CBEM .EQ. 'BEM') THEN
  !
  IF (DTB%LDATA_HC_FLOOR) THEN
    YCOMMENT='Number of specified Floor thermal layers'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,'PAR_FL_LAYER',DTB%NPAR_FLOOR_LAYER,IRESP,YCOMMENT)
  END IF
  !
  YRECFM='L_HC_FLOOR'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_HC_FLOOR,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_HC_FLOOR) THEN
    DO JLAYER=1,DTB%NPAR_FLOOR_LAYER
      WRITE(YRECFM,FMT='(A10,I1.1)') 'D_HC_FLOOR',JLAYER
      YCOMMENT='X_Y_'//YRECFM//' (J/K/m3)'
      CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_HC_FLOOR(:,JLAYER),IRESP,YCOMMENT)
    END DO
  ENDIF
  !
  YRECFM='L_TC_FLOOR'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_TC_FLOOR,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_TC_FLOOR) THEN
    DO JLAYER=1,DTB%NPAR_FLOOR_LAYER
      WRITE(YRECFM,FMT='(A10,I1.1)') 'D_TC_FLOOR',JLAYER
      YCOMMENT='X_Y_'//YRECFM//' (W/K/m)'
      CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_TC_FLOOR(:,JLAYER),IRESP,YCOMMENT)
    END DO
  ENDIF
  !
  YRECFM='L_D_FLOOR'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_D_FLOOR,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_D_FLOOR) THEN
    DO JLAYER=1,DTB%NPAR_FLOOR_LAYER
      WRITE(YRECFM,FMT='(A9,I1.1)') 'D_D_FLOOR',JLAYER
      YCOMMENT='X_Y_'//YRECFM//' (m)'
      CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_D_FLOOR(:,JLAYER),IRESP,YCOMMENT)
    END DO
  ENDIF
  !
  IF (DTB%LDATA_HC_MASS) THEN
    YCOMMENT='Number of specified Mass thermal layers'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,'PAR_MA_LAYER',DTB%NPAR_MASS_LAYER,IRESP,YCOMMENT)
  END IF
  !
  YRECFM='L_HC_MASS'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_HC_MASS,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_HC_MASS) THEN
    DO JLAYER=1,DTB%NPAR_MASS_LAYER
      WRITE(YRECFM,FMT='(A9,I1.1)') 'D_HC_MASS',JLAYER
      YCOMMENT='X_Y_'//YRECFM//' (J/K/m3)'
      CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_HC_MASS(:,JLAYER),IRESP,YCOMMENT)
    END DO
  ENDIF
  !
  YRECFM='L_TC_MASS'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_TC_MASS,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_TC_MASS) THEN
    DO JLAYER=1,DTB%NPAR_MASS_LAYER
      WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TC_MASS',JLAYER
      YCOMMENT='X_Y_'//YRECFM//' (W/K/m)'
      CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_TC_MASS(:,JLAYER),IRESP,YCOMMENT)
    END DO
  ENDIF
  !
  YRECFM='L_D_MASS'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_D_MASS,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_D_MASS) THEN
    DO JLAYER=1,DTB%NPAR_MASS_LAYER
      WRITE(YRECFM,FMT='(A8,I1.1)') 'D_D_MASS',JLAYER
      YCOMMENT='X_Y_'//YRECFM//' (m)'
      CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_D_MASS(:,JLAYER),IRESP,YCOMMENT)
    END DO
  ENDIF
  !
  YCOMMENT='Number of specified compartiments in bem'
  CALL WRITE_SURF(DGU, U, HPROGRAM,'PAR_BEMCOMP',DTB%NPAR_BEMCOMP,IRESP,YCOMMENT)
  !
  YRECFM='L_F_WAST_CAN'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_F_WASTE_CAN,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_F_WASTE_CAN) THEN
    YRECFM='D_F_WAST_CAN'
    YCOMMENT='X_Y_'//YRECFM//' (-)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_F_WASTE_CAN,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_QIN'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_QIN,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_QIN) THEN
    YCOMMENT='X_Y_'//YRECFM//' (K)'
    DO JCOMP=1,DTB%NPAR_BEMCOMP
       WRITE(YRECFM,FMT='(A5,I1.1)') 'D_QIN',JCOMP
       CALL WRITE_SURF(DGU, U, &
          HPROGRAM,YRECFM,DTB%XPAR_QIN(:,JCOMP),IRESP,YCOMMENT)
    ENDDO
  ENDIF
  !
  YRECFM='L_QIN_FRAD'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_QIN_FRAD,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_QIN_FRAD) THEN
    YRECFM='D_QIN_FRAD'
    YCOMMENT='X_Y_'//YRECFM//' (K)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_QIN_FRAD,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_SHGC'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_SHGC,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_SHGC) THEN
    YRECFM='D_SHGC'
    YCOMMENT='X_Y_'//YRECFM//' (-)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_SHGC,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_U_WIN'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_U_WIN,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_U_WIN) THEN
    YRECFM='D_U_WIN'
    YCOMMENT='X_Y_'//YRECFM//' (W m-2 K-1)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_U_WIN,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_GR'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_GR,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_GR) THEN
    YRECFM='D_GR'
    YCOMMENT='X_Y_'//YRECFM//' (-)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_GR,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_SHGC_SH'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_SHGC_SH,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_SHGC_SH) THEN
    YRECFM='D_SHGC_SH'
    YCOMMENT='X_Y_'//YRECFM//' (-)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_SHGC_SH,IRESP,YCOMMENT)
  ENDIF  
  !
  YRECFM='L_FLOOR_HEIG'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_FLOOR_HEIGHT,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_FLOOR_HEIGHT) THEN
    YRECFM='D_FLOOR_HEIG'
    YCOMMENT='X_Y_'//YRECFM//' (m)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_FLOOR_HEIGHT,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_N50'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_N50,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_N50) THEN
    YRECFM='D_N50'
    YCOMMENT='X_Y_'//YRECFM//' (ACH)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_N50,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_QIN_FLAT'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_QIN_FLAT,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_QIN_FLAT) THEN
    YRECFM='D_QIN_FLAT'
    YCOMMENT='X_Y_'//YRECFM//' (-)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_QIN_FLAT,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_HR_TARGET'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_HR_TARGET,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_HR_TARGET) THEN
    YRECFM='D_HR_TARGET'
    YCOMMENT='X_Y_'//YRECFM//' (-)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_HR_TARGET,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_CAP_SYS_HE'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_CAP_SYS_HEAT,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_CAP_SYS_HEAT) THEN
    YRECFM='D_CAP_SYS_HE'
    YCOMMENT='X_Y_'//YRECFM//' (W m-2)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_CAP_SYS_HEAT,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_CAP_SYS_RA'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_CAP_SYS_RAT,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_CAP_SYS_RAT) THEN
    YRECFM='D_CAP_SYS_RA'
    YCOMMENT='X_Y_'//YRECFM//' (W m-2)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_CAP_SYS_RAT,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_T_ADP'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_T_ADP,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_T_ADP) THEN
    YRECFM='D_T_ADP'
    YCOMMENT='X_Y_'//YRECFM//' (K)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_T_ADP,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_M_SYS_RAT'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_M_SYS_RAT,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_M_SYS_RAT) THEN
    YRECFM='D_M_SYS_RAT'
    YCOMMENT='X_Y_'//YRECFM//' (kg s-1 m-)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_M_SYS_RAT,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_COP_RAT'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_COP_RAT,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_COP_RAT) THEN
    YRECFM='D_COP_RAT'
    YCOMMENT='X_Y_'//YRECFM//' (-)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_COP_RAT,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_T_SIZE_MAX'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_T_SIZE_MAX,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_T_SIZE_MAX) THEN
    YRECFM='D_T_SIZE_MAX'
    YCOMMENT='X_Y_'//YRECFM//' (K)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_T_SIZE_MAX,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_T_SIZE_MIN'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_T_SIZE_MIN,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_T_SIZE_MIN) THEN
    YRECFM='D_T_SIZE_MIN'
    YCOMMENT='X_Y_'//YRECFM//' (K)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_T_SIZE_MIN,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_FWAT_COND'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_F_WATER_COND,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_F_WATER_COND) THEN
    YRECFM='D_FWAT_COND'
    YCOMMENT='X_Y_'//YRECFM//' (-)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_F_WATER_COND,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_SHADEARCHI'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_SHADEARCHI,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_SHADEARCHI) THEN
    YRECFM='D_SHADEARCHI'
    YCOMMENT='X_Y_'//YRECFM//' (-)'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%XPAR_SHADEARCHI,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_NATVENT'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTB%LDATA_NATVENT,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_NATVENT) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
       WRITE(YRECFM,FMT='(A9,I1.1)') 'D_NATVENT',JCOMP
       YCOMMENT='X_Y_'//YRECFM//' (-)'
       CALL WRITE_SURF(DGU, U, &
                       HPROGRAM,YRECFM,DTB%XPAR_NATVENT(:,JCOMP),IRESP,YCOMMENT)
    ENDDO
  ENDIF
  !
  YRECFM='L_ISMECH'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                  HPROGRAM,YRECFM,DTB%LDATA_ISMECH,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_ISMECH) THEN
     YRECFM='D_ISMECH'
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_ISMECH,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_MECHRATE'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_MECHRATE,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_MECHRATE) THEN
     YRECFM='D_MECHRATE'
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_MECHRATE,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_FSNIG'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_FSNIG,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_FSNIG) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (1)'
     WRITE(YRECFM,FMT='(A7,I1.1)') 'D_FSNIG',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_FSNIG(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_FVNIG'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_FVNIG,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_FVNIG) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (1)'
     WRITE(YRECFM,FMT='(A7,I1.1)') 'D_FVNIG',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_FVNIG(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_MODQ_VCD'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_MODQIN_VCD,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_MODQIN_VCD) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (1)'
     WRITE(YRECFM,FMT='(A10,I1.1)') 'D_MODQ_VCD',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_MODQIN_VCD(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_MODQ_VLD'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_MODQIN_VLD,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_MODQIN_VLD) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (1)'
     WRITE(YRECFM,FMT='(A10,I1.1)') 'D_MODQ_VLD',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_MODQIN_VLD(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_MODQ_NIG'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_MODQIN_NIG,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_MODQIN_NIG) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (1)'
     WRITE(YRECFM,FMT='(A10,I1.1)') 'D_MODQ_NIG',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_MODQIN_NIG(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TDESV'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_TDESV,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_TDESV) THEN
     YRECFM='D_TDESV'
     YCOMMENT='X_Y_'//YRECFM//' (K)'
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_TDESV,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_FVSHO'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_FVSHO,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_FVSHO) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (K)'
     WRITE(YRECFM,FMT='(A7,I1.1)') 'D_FVSHO',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_FVSHO(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_WIN_SW_MAX'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_WIN_SW_MAX,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_WIN_SW_MAX) THEN
     YRECFM='D_WIN_SW_MAX'
     YCOMMENT='X_Y_'//YRECFM//' (W/m2)'
     CALL WRITE_SURF(DGU, U, &
         HPROGRAM,YRECFM,DTB%XPAR_WIN_SW_MAX,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_FOPEN'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_FOPEN,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_FOPEN) THEN
     YRECFM='D_FOPEN'
     YCOMMENT='X_Y_'//YRECFM//' (1)'
     CALL WRITE_SURF(DGU, U, &
       HPROGRAM,YRECFM,DTB%XPAR_FOPEN,IRESP,YCOMMENT)
  ENDIF
  !
  YRECFM='L_FVSUM'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_FVSUM,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_FVSUM) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (1)'
     WRITE(YRECFM,FMT='(A7,I1.1)') 'D_FVSUM',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_FVSUM(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_FVVAC'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_FVVAC,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_FVVAC) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_FVVAC'//YRECFM//' (1)'
     WRITE(YRECFM,FMT='(A7,I1.1)') 'D_FVVAC',JCOMP
     CALL WRITE_SURF(DGU, U, &
       HPROGRAM,YRECFM,DTB%XPAR_FVVAC(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_FSSUM'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_FSSUM,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_FSSUM) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_FSSUM'//YRECFM//' (1)'
     WRITE(YRECFM,FMT='(A7,I1.1)') 'D_FSSUM',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_FSSUM(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_FSVAC'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_FSVAC,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_FSVAC) THEN
    DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_FSVAC'//YRECFM//' (1)'
     WRITE(YRECFM,FMT='(A7,I1.1)') 'D_FSVAC',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_FSVAC(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TC_OCCD'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_TCOOL_OCCD,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_TCOOL_OCCD) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
     WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TC_OCCD',JCOMP
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_TCOOL_OCCD(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TC_OCCN'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_TCOOL_OCCN,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_TCOOL_OCCN) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TC_OCCN',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_TCOOL_OCCN(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TC_VCDD'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_TCOOL_VCDD,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_TCOOL_VCDD) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TC_VCDD',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_TCOOL_VCDD(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TC_VCDN'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_TCOOL_VCDN,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_TCOOL_VCDN) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TC_VCDN',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_TCOOL_VCDN(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TC_VCLD'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_TCOOL_VCLD,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_TCOOL_VCLD) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TC_VCLD',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_TCOOL_VCLD(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TH_OCCD'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_THEAT_OCCD,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_THEAT_OCCD) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TH_OCCD',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_THEAT_OCCD(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TH_OCCN'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_THEAT_OCCN,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_THEAT_OCCN) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TH_OCCN',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_THEAT_OCCN(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TH_VCDD'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_THEAT_VCDD,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_THEAT_VCDD) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TH_VCDD',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_THEAT_VCDD(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TH_VCDN'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_THEAT_VCDN,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_THEAT_VCDN) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TH_VCDN',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_THEAT_VCDN(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_TH_VCLD'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
      HPROGRAM,YRECFM,DTB%LDATA_THEAT_VCLD,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_THEAT_VCLD) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
     YCOMMENT='X_Y_'//YRECFM//' (-)'
     WRITE(YRECFM,FMT='(A9,I1.1)') 'D_TH_VCLD',JCOMP
     CALL WRITE_SURF(DGU, U, &
        HPROGRAM,YRECFM,DTB%XPAR_THEAT_VCLD(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YCOMMENT='Number of days distinguished in schedules'
  CALL WRITE_SURF(DGU, U, &
    HPROGRAM,'PAR_DAY_SCHED',DTB%NPAR_DAY_SCHED,IRESP,YCOMMENT)
  !
  YCOMMENT='Number of hours distinguished in schedules'
  CALL WRITE_SURF(DGU, U, &
    HPROGRAM,'PAR_CRE_SCHED',DTB%NPAR_CRE_SCHED,IRESP,YCOMMENT)
  !
  YCOMMENT='Number of holidays'
  CALL WRITE_SURF(DGU, U, &
    HPROGRAM,'PAR_NHOLIDAY',DTB%NPAR_HOLIDAY,IRESP,YCOMMENT)
  !
  YRECFM='L_FRACOMP'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_FRACOMP,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_FRACOMP) THEN
     YCOMMENT='X_Y_'//YRECFM//' (h)'
     DO JCOMP=1,DTB%NPAR_BEMCOMP
        WRITE(YRECFM,FMT='(A9,I1.1)') 'D_FRACOMP',JCOMP
        CALL WRITE_SURF(DGU, U, &
           HPROGRAM,YRECFM,DTB%XPAR_FRACOMP(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
  YRECFM='L_DAYBEGS'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_DAYWBEG_SCHED,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_DAYWBEG_SCHED) THEN
     YCOMMENT='X_Y_'//YRECFM//' (h)'
     DO JSCHED=1,DTB%NPAR_DAY_SCHED
        DO JCOMP=1,DTB%NPAR_BEMCOMP
          WRITE(YRECFM,FMT='(A9,I2.2,I1.1)') 'D_DAYBEGS',JSCHED,JCOMP
          CALL WRITE_SURF(DGU, U, &
             HPROGRAM,YRECFM,DTB%XPAR_DAYWBEG_SCHED(:,JSCHED,JCOMP),IRESP,YCOMMENT)
        ENDDO
     ENDDO
  ENDIF
  !
  YRECFM='L_HOUBEGS'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_HOURBEG_SCHED,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_HOURBEG_SCHED) THEN
     YCOMMENT='X_Y_'//YRECFM//' (h)'
     DO JSCHED=1,(DTB%NPAR_DAY_SCHED*DTB%NPAR_CRE_SCHED)
        DO JCOMP=1,DTB%NPAR_BEMCOMP
           WRITE(YRECFM,FMT='(A9,I2.2,I1.1)') 'D_HOUBEGS',JSCHED,JCOMP
           CALL WRITE_SURF(DGU, U, &
             HPROGRAM,YRECFM,DTB%XPAR_HOURBEG_SCHED(:,JSCHED,JCOMP),IRESP,YCOMMENT)
        ENDDO
     ENDDO
  ENDIF
  !
  YRECFM='L_PROBOCC'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_PROBOCC,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_PROBOCC) THEN
     YCOMMENT='X_Y_'//YRECFM//' (h)'
     DO JSCHED=1,(DTB%NPAR_DAY_SCHED*DTB%NPAR_CRE_SCHED)
        DO JCOMP=1,DTB%NPAR_BEMCOMP
           WRITE(YRECFM,FMT='(A9,I2.2,I1.1)') 'D_PROBOCC',JSCHED,JCOMP
           CALL WRITE_SURF(DGU, U, &
              HPROGRAM,YRECFM,DTB%XPAR_PROBOCC(:,JSCHED,JCOMP),IRESP,YCOMMENT)
        ENDDO
     ENDDO
  ENDIF
  !
  YRECFM='L_BEG_HOLIDAY'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_BEG_HOLIDAY,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_BEG_HOLIDAY) THEN
     YCOMMENT='X_Y_'//YRECFM//' (day)'
     DO JSCHED=1,DTB%NPAR_HOLIDAY
        DO JCOMP=1,DTB%NPAR_BEMCOMP
           WRITE(YRECFM,FMT='(A8,I1.1,I1.1)') 'D_BEGHOL',JSCHED,JCOMP
           CALL WRITE_SURF(DGU, U, &
              HPROGRAM,YRECFM,DTB%XPAR_BEG_HOLIDAY(:,JSCHED,JCOMP),IRESP,YCOMMENT)
        ENDDO
     ENDDO
  ENDIF
  !
  YRECFM='L_END_HOLIDAY'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
     HPROGRAM,YRECFM,DTB%LDATA_END_HOLIDAY,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_END_HOLIDAY) THEN
     YCOMMENT='X_Y_'//YRECFM//' (day)'
     DO JSCHED=1,DTB%NPAR_HOLIDAY
        DO JCOMP=1,DTB%NPAR_BEMCOMP
           WRITE(YRECFM,FMT='(A8,I1.1,I1.1)') 'D_ENDHOL',JSCHED,JCOMP
           CALL WRITE_SURF(DGU, U, &
              HPROGRAM,YRECFM,DTB%XPAR_END_HOLIDAY(:,JSCHED,JCOMP),IRESP,YCOMMENT)
        ENDDO
     ENDDO
  ENDIF
  !
  YRECFM='L_MOD_HOLIDAY'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
      HPROGRAM,YRECFM,DTB%LDATA_MOD_HOLIDAY,IRESP,HCOMMENT=YCOMMENT)
  IF (DTB%LDATA_MOD_HOLIDAY) THEN
     DO JCOMP=1,DTB%NPAR_BEMCOMP
        YCOMMENT='X_Y_'//YRECFM//' (-)'
        WRITE(YRECFM,FMT='(A8,I1.1)') 'D_MODHOL',JCOMP
        CALL WRITE_SURF(DGU, U, &
          HPROGRAM,YRECFM,DTB%XPAR_MOD_HOLIDAY(:,JCOMP),IRESP,YCOMMENT)
     ENDDO
  ENDIF
  !
ENDIF
!
! Flag for data for gardens
YRECFM='PAR_GARDEN'
YCOMMENT='FLAG FOR SPECIFIED GARDEN PARAMETERS'
 CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,TGDO%LPAR_GARDEN,IRESP,HCOMMENT=YCOMMENT)
!
IF (TOP%LGARDEN .AND. TGDO%LPAR_GARDEN) THEN
!
  YRECFM='GD_NTIME'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGD%NTIME,IRESP,HCOMMENT=YCOMMENT)
!
! Type of high vegetation
  YRECFM='D_TYPE_HVEG'
  YCOMMENT='X_Y_TYPE_HVEG'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,TGDP%CTYPE_HVEG,IRESP,HCOMMENT=YCOMMENT)
!
! Type of low vegetation
  YRECFM='D_TYPE_LVEG'
  YCOMMENT='X_Y_TYPE_LVEG'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,TGDP%CTYPE_LVEG,IRESP,HCOMMENT=YCOMMENT)
!
! Type of bare soil (no vegetation)
  YRECFM='D_TYPE_NVEG'
  YCOMMENT='X_Y_TYPE_NVEG'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,TGDP%CTYPE_NVEG,IRESP,HCOMMENT=YCOMMENT)
!
! Fraction of high vegetation
  YRECFM='D_FRAC_HVEG'
  YCOMMENT='X_Y_D_FRAC_HVEG'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGD%XPAR_FRAC_HVEG(:),IRESP,HCOMMENT=YCOMMENT)
!
! Fraction of low vegetation
  YRECFM='D_FRAC_LVEG'
  YCOMMENT='X_Y_D_FRAC_LVEG'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGD%XPAR_FRAC_LVEG(:),IRESP,HCOMMENT=YCOMMENT)
!
! Fraction of bare soil
  YRECFM='D_FRAC_NVEG'
  YCOMMENT='X_Y_D_FRAC_NVEG'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGD%XPAR_FRAC_NVEG(:),IRESP,HCOMMENT=YCOMMENT)
!
! LAI of high vegetation
  DO JTIME=1,DTGD%NTIME
    WRITE(YRECFM,FMT='(A10,I2.2)') 'D_LAI_HVEG',JTIME
    YCOMMENT='X_Y_D_LAI_HVEG'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGD%XPAR_LAI_HVEG(:,JTIME),IRESP,HCOMMENT=YCOMMENT)
  END DO
!
! LAI of low vegetation
  DO JTIME=1,DTGD%NTIME
    WRITE(YRECFM,FMT='(A10,I2.2)') 'D_LAI_LVEG',JTIME
    YCOMMENT='X_Y_D_LAI_LVEG'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGD%XPAR_LAI_LVEG(:,JTIME),IRESP,HCOMMENT=YCOMMENT)
  END DO
!
! Height of trees
  YRECFM='D_H_HVEG'
  YCOMMENT='X_Y_DATA_H_HVEG'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGD%XPAR_H_HVEG(:),IRESP,HCOMMENT=YCOMMENT)
!
ENDIF
!
IF (TOP%LGREENROOF .AND. TGRO%LPAR_GREENROOF) THEN
!
! Type of green roof
  YRECFM='D_TYPE_GR'
  YCOMMENT='X_Y_TYPE_GR'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,TGRO%CTYP_GR,IRESP,HCOMMENT=YCOMMENT)
!
! Fraction of OM in green roof layer
  DO JLAYER=1,TGRO%NLAYER_GR
    WRITE(YRECFM,FMT='(A7,I2.2)') 'D_OM_GR',JLAYER
    YCOMMENT='X_Y_D_OM_GR'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGR%XPAR_OM_GR(:,JLAYER),IRESP,HCOMMENT=YCOMMENT)
  END DO
!
! Fraction of CLAY in the non-OM part of the green roof layer
  DO JLAYER=1,TGRO%NLAYER_GR
    WRITE(YRECFM,FMT='(A9,I2.2)') 'D_CLAY_GR',JLAYER
    YCOMMENT='X_Y_D_CLAY_GR'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGR%XPAR_CLAY_GR(:,JLAYER),IRESP,HCOMMENT=YCOMMENT)
  END DO
!
! Fraction of SAND in the non-OM part of the green roof layer
  DO JLAYER=1,TGRO%NLAYER_GR
    WRITE(YRECFM,FMT='(A9,I2.2)') 'D_SAND_GR',JLAYER
    YCOMMENT='X_Y_D_SAND_GR'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGR%XPAR_SAND_GR(:,JLAYER),IRESP,HCOMMENT=YCOMMENT)
  END DO
!
! LAI of green roof vegetation
  DO JTIME=1,TGRO%NTIME_GR
    WRITE(YRECFM,FMT='(A8,I2.2)') 'D_LAI_GR',JTIME
    YCOMMENT='X_Y_D_LAI_GR'
    CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGR%XPAR_LAI_GR(:,JTIME),IRESP,HCOMMENT=YCOMMENT)
  END DO
! 
ENDIF
!
IF (TOP%CURBTREE .EQ. 'TREE') THEN
! Shape of crown of urban trees
  YRECFM='D_CSHAP_HVEG'
  YCOMMENT='X_Y_CSHAPE_HVEG'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,TGDP%CSHAPE_HVEG,IRESP,HCOMMENT=YCOMMENT)
! Height of trunk of urban trees
  YRECFM='D_HTRUN_HVEG'
  YCOMMENT='X_Y_D_HTRUNK_HVEG'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGD%XPAR_HTRUNK_HVEG(:),IRESP,HCOMMENT=YCOMMENT)
! Width of crown of urban trees
  YRECFM='D_WCROW_HVEG'
  YCOMMENT='X_Y_D_WCROWN_HVEG'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTGD%XPAR_WCROWN_HVEG(:),IRESP,HCOMMENT=YCOMMENT)
ENDIF 
!
IF (TOP%LURBHYDRO) THEN
! Waste water sewer length
  YRECFM='D_LSEWER'
  YCOMMENT='X_Y_LSEWER'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTH%XPAR_LSEWER,IRESP,HCOMMENT=YCOMMENT)
! Storm water sewer length
  YRECFM='D_LSTORM'
  YCOMMENT='X_Y_LSTORM'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTH%XPAR_LSTORM,IRESP,HCOMMENT=YCOMMENT)
! Waste water sewer depth
  YRECFM='D_DSEWER'
  YCOMMENT='X_Y_DSEWER'
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTH%XPAR_DSEWER,IRESP,HCOMMENT=YCOMMENT)
! Max. capacity of surface roof water storage
  YRECFM='D_WS_RF_MAX'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTH%XPAR_WS_ROOF_MAX,IRESP,HCOMMENT=YCOMMENT)
! Max. capacity of surface road water storage
  YRECFM='D_WS_RD_MAX'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTH%XPAR_WS_ROAD_MAX,IRESP,HCOMMENT=YCOMMENT)
! Parameter for parasite infiltrations into sewer
  YRECFM='D_IP_SEWER'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTH%XPAR_IP_SEWER,IRESP,HCOMMENT=YCOMMENT)
! Impervious surfaces connexion rate to the sewer
  YRECFM='D_CONNEX'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTH%XPAR_CONNEX,IRESP,HCOMMENT=YCOMMENT)
! Water infiltration through the roads
  YRECFM='D_INFIL_RD'
  YCOMMENT=YRECFM
  CALL WRITE_SURF(DGU, U, &
                 HPROGRAM,YRECFM,DTH%XPAR_INFIL_ROAD,IRESP,HCOMMENT=YCOMMENT)
ENDIF 
!
!-------------------------------------------------------------------------------
!
!*      Irrigation of gardens or greenroofs
!       -----------------------------------
!
CALL WRITESURF_PGD_TEB_IRRIG_n(DGU, U, &
                               TIR, &
                               HPROGRAM)
!
IF (LHOOK) CALL DR_HOOK('WRITESURF_PGD_TEB_PAR_N',1,ZHOOK_HANDLE)
!
!
!-------------------------------------------------------------------------------
!
END SUBROUTINE WRITESURF_PGD_TEB_PAR_n
